@@ -1,10 +1,11 @@
 package DTL::Fast;
 use strict; use warnings FATAL => 'all'; 
 use parent 'Exporter';
-use Carp qw(confess);
+use Carp;
+use Storable qw(freeze thaw);
 
 use 5.010;
-our $VERSION = '1.03';
+our $VERSION = '1.04';
 
 use Cwd;
 use DTL::Fast::Template;
@@ -25,10 +26,10 @@ sub get_template
     my $dirs = shift // [getcwd()];
     my %kwargs = @_;
     
-    confess "Template name was not specified" 
+    croak  "Template name was not specified" 
         if not $template_name;
     
-    confess "Second parameter must be a dirs array reference" 
+    croak  "Second parameter must be a dirs array reference" 
         if(
             not ref $dirs
             or ref $dirs ne 'ARRAY'
@@ -53,55 +54,20 @@ sub get_template
     {
         my $template_path;
 
-        ($template, $template_path) = _read_template($template_name, $dirs);
-        $template =~ s/\{\% (?:block|endblock|extends) .*?\%\}//gs;
+        ($template, $template_path) = _read_template($template_name, $dirs, { '*path' => [] }, %kwargs );
         
-        my @arguments = (
-            $template
-            , $dirs
-            , 'file_path' => $template_path
-        );
-        push @arguments, 'ssi_dirs', $kwargs{'ssi_dirs'}
-            if $kwargs{'ssi_dirs'};
-        push @arguments, 'url_source', $kwargs{'url_source'}
-            if $kwargs{'url_source'};
-        
-        $template = DTL::Fast::Template->new(@arguments)
-            if defined $template;
-        $OBJECTS_CACHE{$cache_key} = $template;
-    }
-    
-    return $template;
-}
-
-sub _apply_inheritance
-{
-    my $template = shift;
-    my $dirs = shift;
-    my $inheritance_path = shift;
-    
-    if( $template =~ s/\s*\{\% extends\s*"(.+?)" \%\}//s ) # template has inheritance
-    {
-        my $parent_name = $1;
-        my( $parent_template, $parent_template_path) = _read_template($parent_name, $dirs, $inheritance_path);
-        
-        if( defined $parent_template )
+        if( defined $template )
         {
-            my %named_blocks = (
-                $template =~ /\{\% block ([^\s]+) \%\}(.+?)\{\% endblock \%\}/gs
-            );
-            
-            my $block_names = join '|', keys(%named_blocks);
-            $parent_template =~ s/\{\% block ($block_names) \%\}.+?\{\% endblock \%\}/\{\% block $1 \%\}$named_blocks{$1}\{\% endblock \%\}/gsi;
-            $template = $parent_template;
+            $OBJECTS_CACHE{$cache_key} = $template;
         }
         else
         {
-            die sprintf( "Couldn't found a parent template: %s in one of the following directories: %s"
-                , $parent_name
-                , join( ', ', @$dirs)
-            );
+            croak  sprintf( <<'_EOT_', $template_name, join("\n", @$dirs)) if not defined $template;
+Unable to find template %s in directories: 
+%s
+_EOT_
         }
+            
     }
     
     return $template;
@@ -112,7 +78,8 @@ sub _read_template
     my $template_name = shift;
     my $dirs = shift;
     my $inheritance_path = shift // { '*path' => [] };
-
+    my %kwargs = @_;
+    
     my $template = undef;
     my $template_path = undef;
 
@@ -123,7 +90,7 @@ sub _read_template
 
     if( exists $TEMPLATES_CACHE{$cache_key} )   # already read template with this parameters
     {
-        $template = $TEMPLATES_CACHE{$cache_key};
+        $template = thaw($TEMPLATES_CACHE{$cache_key});
         $TEMPLATES_CACHE_HITS++;
     }
     else
@@ -134,32 +101,61 @@ sub _read_template
         {
             if( exists $inheritance_path->{$template_path} )
             {
-                die sprintf(
+                croak  sprintf(
                     "Recursive inheritance detected:\n%s\n" 
                     , join "\n inherited from ", @{$inheritance_path->{'*path'}}, $template_path
                 );
             }
+
+            my @arguments = (
+                $template
+                , $dirs
+                , 'file_path' => $template_path
+            );
+            push @arguments, 'ssi_dirs', $kwargs{'ssi_dirs'}
+                if $kwargs{'ssi_dirs'};
+            push @arguments, 'url_source', $kwargs{'url_source'}
+                if $kwargs{'url_source'};
             
-            push @{$inheritance_path->{'*path'}}, $template_path;
-            $inheritance_path->{$template_path} = 1;
-            
-            $template = _apply_inheritance($template, $dirs, $inheritance_path);
+            $template = DTL::Fast::Template->new(@arguments);
+
+            if( $template->{'_extends' })  # template is inherited
+            {
+                push @{$inheritance_path->{'*path'}}, $template_path;
+                $inheritance_path->{$template_path} = 1;
+
+                my ($parent_template, $parent_template_path) = _read_template(
+                    $template->{'_extends' }
+                    , $dirs
+                    , $inheritance_path
+                    , %kwargs
+                );
                 
-            pop @{$inheritance_path->{'*path'}};
-            delete $inheritance_path->{$template_path};
+                if( defined $parent_template )
+                {
+                    $template = $parent_template->merge_blocks($template);
+                }
+                else
+                {
+                    croak  sprintf( "Couldn't found a parent template: %s in one of the following directories: %s"
+                        , $template->{'_extends' }
+                        , join( ', ', @$dirs)
+                    );
+                }
+                    
+                pop @{$inheritance_path->{'*path'}};
+                delete $inheritance_path->{$template_path};
+            }
+            
+            $TEMPLATES_CACHE{$cache_key} = freeze($template);
         }
             
-        $TEMPLATES_CACHE{$cache_key} = $template;
     }
-
-    confess sprintf( <<'_EOT_', $template_name, join("\n", @$dirs)) if not defined $template;
-Unable to find template %s in directories: 
-%s
-_EOT_
     
     return ($template, $template_path);
 }
 
+
 sub _read_file
 {
     my $template_name = shift;
@@ -185,7 +181,7 @@ sub _read_file
             }
             else
             {
-                confess sprintf(
+                croak  sprintf(
                     'Error opening file %s, %s'
                     , $template_path
                     , $!
@@ -204,7 +200,7 @@ sub select_template
     my $template_names = shift;
     my $dirs = shift // [getcwd()];
     
-    confess "First parameter must be a template names array reference" 
+    croak  "First parameter must be a template names array reference" 
         if(
             not ref $template_names
             or ref $template_names ne 'ARRAY'
@@ -233,7 +229,7 @@ DTL::Fast - Perl implementation of Django templating language.
 
 =head1 VERSION
 
-Version 1.03
+Version 1.04
 
 =head1 SYNOPSIS
 
@@ -380,8 +376,6 @@ This module supports all built-in filters documented on L<official Django site|h
 
 =over
 
-=item * Date and time formatting being done using L<C<Date::Format>> module, which uses C library routines C<strftime> and C<ctime>. Django uses it's own L<placeholders|https://docs.djangoproject.com/en/1.7/ref/templates/builtins/#date>. (Mapping considered atm.)
-
 =item * C<ssi> tag in Django uses absolute paths and C<ALLOWED_INCLUDE_ROOTS> configuration option. This library works separately and may be used with different frameworks. So, C<ssi> tag uses relative paths and you MUST specify additional template constructor parameter: C<ssi_dirs> which should be an array reference with list of dirs to search in.
 
 =item * C<csrf_token> tag is not implemented, too well connected with Django.
@@ -412,6 +406,8 @@ May be some of this features implemented in Django itself. Let me know about it.
 
 =over
 
+=item * C<strftime> - new filter. Formatting time using L<C<Date::Format>> module, which is using C functions C<strftime> and C<ctime>.
+
 =item * C<firstofdefined> - new tag, that works like C<firstof> tag, but checks if value is defined (not true)
 
 =item * C<defined> logical operator. In logical constructions you may use C<defined> operator, which works exactly like perl's C<defined>
@@ -518,6 +514,29 @@ Tests shows, that C<DTL::Fast> works 26% slower, than L<C<Dotiac::DTL>> in CGI e
 
 =over
 
+=item * 14/01/2015 - v1.04
+
+=over
+
+=item * Taken C<date> function from L<C<Dotiac::DTL>> to C<DTL::Fast::Utils::time2str_php>
+
+=item * C<now> tag and C<date> filter now works with C<time2str_php> function (like Django itself)
+
+=item * Implemented C<strftime> filter, which works with L<C<Date::Format>> C<str2time>.
+
+=item * Added Russian version of C<pluralize> filter:
+
+    use DTL::Fast;
+    use DTL::Fast::Template::Filter::Ru::Pluralize; # this will override default pluralize with Russian version.
+
+=item * Refactored strings backup and parametrized filters.
+
+=item * C<block> and C<extends> tags now works as tags.
+
+=item * New dependency added: L<C<Storable>>
+    
+=back
+
 =item * 13/01/2015 - v1.03
 
 =over
