@@ -6,8 +6,8 @@ use DTL::Fast::Utils qw(has_method);
 
 sub new
 {
-    my( $proto, $context ) = @_;
-    $context //= {};
+    my $proto = shift;
+    my $context = shift // {};
     
     croak  "Context should be a HASH reference"
         if ref $context ne 'HASH';
@@ -19,11 +19,12 @@ sub new
 
 sub get
 {
-    my( $self, $variable_path ) = @_;
+    my $self = shift;
+    my $variable_path = shift;
 
     if( ref $variable_path ne 'ARRAY' )    # suppose that raw variable invoked, period separated
     {
-        $variable_path = [split /\.+/x, $variable_path];
+        $variable_path = [split /\.+/, $variable_path];
     }
     else
     {
@@ -38,10 +39,8 @@ sub get
         $namespace->{$variable_name}
         : undef; 
 
-    while( ref $variable eq 'CODE' )
-    {
-        $variable = $variable->($self) 
-    }
+    $variable = $variable->($self) 
+        if ref $variable eq 'CODE';
         
     $variable = $self->traverse($variable, $variable_path)
         if 
@@ -54,7 +53,9 @@ sub get
 # tracing variable path
 sub traverse
 {
-    my( $self, $variable, $path ) = @_;
+    my $self = shift;
+    my $variable = shift;
+    my $path = shift;
 
     foreach my $step (@$path)
     {
@@ -65,7 +66,7 @@ sub traverse
         }
         elsif( 
             $current_type eq 'ARRAY'
-            and $step =~ /^\-?\d+$/x
+            and $step =~ /^\-?\d+$/
         )
         {
             $variable = $variable->[$step];
@@ -74,10 +75,6 @@ sub traverse
         {
             $variable = $variable->$step($self);
         }
-        elsif( $current_type )
-        {
-            $variable = $variable->{$step};
-        }
         else
         {
             croak  sprintf("Don't know how to traverse %s (%s) with %s"
@@ -87,26 +84,26 @@ sub traverse
             );
         }        
     }
-
-    while( ref $variable eq 'CODE' )
-    {
-        $variable = $variable->($self);
-    }
+        
+    $variable = $variable->($self) 
+        if ref $variable eq 'CODE';
 
     return $variable;
 }
 
 sub set
 {
-    my( $self, @sets ) = @_;
+    my $self = shift;
+    my @sets = @_;
     
-    while( scalar @sets > 1 )
+    while( 
+        defined (my $key = shift @sets)
+        and defined (my $val = shift @sets)
+    )
     {
-        my $key = shift @sets;
-        my $val = shift @sets;
-        if( $key =~ /\./x )  # traversed set
+        if( $key =~ /\./ )  # traversed set
         {
-            my @key = split /\.+/x, $key;
+            my @key = split /\.+/, $key;
             my $variable_name = pop @key;
             my $variable = $self->get([@key]);
             
@@ -122,7 +119,7 @@ sub set
             }
             elsif( 
                 $variable_type eq 'ARRAY'
-                and $variable_name =~ /^\-?\d+$/x
+                and $variable_name =~ /^\-?\d+$/
             )
             {
                 $variable->[$variable_name] = $val;
@@ -143,17 +140,17 @@ sub set
     return $self;
 }
 
-sub push_scope
+sub push
 {
-    my( $self ) = @_;
+    my $self = shift;
 #    push @{$self->{'ns'}}, {}; # multi-level version, suppose it's slower on reading
     push @{$self->{'ns'}}, {%{$self->{'ns'}->[-1] // {}}};
     return $self;
 }
 
-sub pop_scope
+sub pop
 {
-    my( $self ) = @_;
+    my $self = shift;
     croak  "It's a last context layer available."
         if scalar @{$self->{'ns'}} ==  1;
     pop @{$self->{'ns'}};
