@@ -1,7 +1,7 @@
 package DTL::Fast::Template::Filter::Cut;
 use strict; use utf8; use warnings FATAL => 'all'; 
 use parent 'DTL::Fast::Template::Filter';
-use Carp qw(confess);
+use Carp;
 
 $DTL::Fast::Template::FILTER_HANDLERS{'cut'} = __PACKAGE__;
 
@@ -12,9 +12,9 @@ use DTL::Fast::Template::Variable;
 sub parse_parameters
 {
     my $self = shift;
-    die "No substitute specified for removing"
+    croak "No substitute specified for removing"
         if not scalar @{$self->{'parameter'}};
-    $self->{'remove'} = DTL::Fast::Template::Variable->new($self->{'parameter'}->[0]);
+    $self->{'remove'} = $self->{'parameter'}->[0];
     return $self;
 }
 
