@@ -1,4 +1,4 @@
-#!/usr/bin/perl -I./blib/lib -I./blib/arch
+#!/usr/bin/perl -I./lib/
 
 use Test::Harness;
 
@@ -7,7 +7,6 @@ runtests(
     't/core/expression.t',
     't/core/loader.t',
     't/core/template.t',
-    't/expression/logic.t',
     't/expression/in.t',
     't/expression/eq.t',
     't/expression/defined.t',
@@ -91,5 +90,4 @@ runtests(
     't/tag/verbatim.t',
     't/tag/widthratio.t',
     't/tag/with.t',
-    't/xs/spaceless.t',
 );
\ No newline at end of file
